@@ -270,13 +270,13 @@ class EventbridgeToStepfunctionsProps:
         :summary: The properties for the EventbridgeToStepfunctions Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = RuleProps(**event_rule_props)
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
-            state_machine_props = StateMachineProps(**state_machine_props)
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = EventBusProps(**event_bus_props)
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(EventbridgeToStepfunctionsProps.__init__)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
